@@ -1,9 +1,11 @@
+"""Sansorchi a pakage for remove swears word"""
+
 from .data import fa
 
-Json = fa["word"]
+json_data = fa["word"]
 
 
-def sansor(txt: str, bad=Json, lang="fa", **kwargs) -> str:
+def sansor(txt: str, bad=json_data, lang="fa") -> str:
     """This function takes an obligatory input called
     txt and deletes it if there is an insult in it
     >>> sansor('موز خر است') == "م**ز خ**ر است' # Farsi
@@ -14,13 +16,13 @@ def sansor(txt: str, bad=Json, lang="fa", **kwargs) -> str:
 
     split = txt.split(" ")
 
-    a = ""
+    return_txt = ""
     for i in split:
         if i in bad:
             badi = str(i[0]) + "**" + str(i[-1])
-            a += badi
+            return_txt += badi
         else:
-            a += i
+            return_txt += i
         if split[-1] != i:
-            a += " "
-    return a
+            return_txt += " "
+    return return_txt
